SentryLoggerFormatter class abstract interface

Interface for formatted logging with template strings.

Access via SentryLogger.fmt.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at DEBUG level.
error(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at ERROR level.
fatal(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at FATAL level.
info(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at INFO level.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trace(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at TRACE level.
warn(String templateBody, List arguments, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a formatted message at WARN level.

Operators

operator ==(Object other) bool
The equality operator.
inherited