setAttribute abstract method
Sets an attribute on this span, replacing any existing attribute with the same key.
Implementation
void setAttribute(String key, SentryAttribute value);
Sets an attribute on this span, replacing any existing attribute with the same key.
void setAttribute(String key, SentryAttribute value);